pub struct Theme {
    pub background: &'static str,
    pub editor_bg: &'static str,
    pub editor_bg_focus: &'static str,
    pub text: &'static str,
    pub popup_bg: &'static str,
    pub popup_border: &'static str,
    pub popup_shadow: &'static str,
    pub suggestion_text: &'static str,
    pub suggestion_bg_hover: &'static str,
    pub suggestion_bg_selected: &'static str,
    pub suggestion_text_selected: &'static str,
    pub scrollbar_track: &'static str,
    pub scrollbar_thumb: &'static str,
    pub scrollbar_thumb_hover: &'static str,
}

pub fn get_theme(name: &str) -> Theme {
    match name {
        "pastel" => Theme {
            background: "#f7f3f7",
            editor_bg: "#fdfafd",
            editor_bg_focus: "#ffffff",
            text: "#4a4a4a",
            popup_bg: "#fdfafd",
            popup_border: "#e8d4e8",
            popup_shadow: "rgba(0, 0, 0, 0.1)",
            suggestion_text: "#4a4a4a",
            suggestion_bg_hover: "#f5e6f5",
            suggestion_bg_selected: "#e8d4e8",
            suggestion_text_selected: "#2a2a2a",
            scrollbar_track: "#fdfafd",
            scrollbar_thumb: "#e8d4e8",
            scrollbar_thumb_hover: "#d8b4d8",
        },
        "light" => Theme {
            background: "#f5f5f5",
            editor_bg: "#fcfcfc",
            editor_bg_focus: "#ffffff",
            text: "#2c2c2c",
            popup_bg: "#fcfcfc",
            popup_border: "#e0e0e0",
            popup_shadow: "rgba(0, 0, 0, 0.1)",
            suggestion_text: "#2c2c2c",
            suggestion_bg_hover: "#f0f0f0",
            suggestion_bg_selected: "#e0e0e0",
            suggestion_text_selected: "#1a1a1a",
            scrollbar_track: "#fcfcfc",
            scrollbar_thumb: "#e0e0e0",
            scrollbar_thumb_hover: "#d0d0d0",
        },
        "dracula" => Theme {
            background: "#282a36",
            editor_bg: "#1e1f29",
            editor_bg_focus: "#20212c",
            text: "#f8f8f2",
            popup_bg: "#282a36",
            popup_border: "#44475a",
            popup_shadow: "rgba(0, 0, 0, 0.3)",
            suggestion_text: "#f8f8f2",
            suggestion_bg_hover: "#44475a",
            suggestion_bg_selected: "#6272a4",
            suggestion_text_selected: "#f8f8f2",
            scrollbar_track: "#282a36",
            scrollbar_thumb: "#44475a",
            scrollbar_thumb_hover: "#6272a4",
        },
        "nord" => Theme {
            background: "#2e3440",
            editor_bg: "#242933",
            editor_bg_focus: "#272c36",
            text: "#d8dee9",
            popup_bg: "#2e3440",
            popup_border: "#3b4252",
            popup_shadow: "rgba(0, 0, 0, 0.3)",
            suggestion_text: "#d8dee9",
            suggestion_bg_hover: "#3b4252",
            suggestion_bg_selected: "#434c5e",
            suggestion_text_selected: "#e5e9f0",
            scrollbar_track: "#2e3440",
            scrollbar_thumb: "#3b4252",
            scrollbar_thumb_hover: "#434c5e",
        },
        "monokai" => Theme {
            background: "#272822",
            editor_bg: "#1e1f1c",
            editor_bg_focus: "#222420",
            text: "#f8f8f2",
            popup_bg: "#272822",
            popup_border: "#3e3d32",
            popup_shadow: "rgba(0, 0, 0, 0.3)",
            suggestion_text: "#f8f8f2",
            suggestion_bg_hover: "#3e3d32",
            suggestion_bg_selected: "#75715e",
            suggestion_text_selected: "#f8f8f2",
            scrollbar_track: "#272822",
            scrollbar_thumb: "#3e3d32",
            scrollbar_thumb_hover: "#75715e",
        },
        "solarized-dark" => Theme {
            background: "#002b36",
            editor_bg: "#001e26",
            editor_bg_focus: "#00222b",
            text: "#839496",
            popup_bg: "#002b36",
            popup_border: "#073642",
            popup_shadow: "rgba(0, 0, 0, 0.3)",
            suggestion_text: "#839496",
            suggestion_bg_hover: "#073642",
            suggestion_bg_selected: "#586e75",
            suggestion_text_selected: "#93a1a1",
            scrollbar_track: "#002b36",
            scrollbar_thumb: "#073642",
            scrollbar_thumb_hover: "#586e75",
        },
        _ => Theme {
            // Tokyo Night
            background: "#1a1b26",
            editor_bg: "#16161e",
            editor_bg_focus: "#1a1b26",
            text: "#a9b1d6",
            popup_bg: "#1a1b26",
            popup_border: "#24283b",
            popup_shadow: "rgba(0, 0, 0, 0.3)",
            suggestion_text: "#a9b1d6",
            suggestion_bg_hover: "#24283b",
            suggestion_bg_selected: "#414868",
            suggestion_text_selected: "#c0caf5",
            scrollbar_track: "#1a1b26",
            scrollbar_thumb: "#24283b",
            scrollbar_thumb_hover: "#414868",
        },
    }
}
